@@ -24,7 +24,7 @@
 #'
 #' Note that we can use `var.type="Vc"` here (see `gamObject`), which is the
 #' variance-covariance matrix for the spatial model, corrected for smoothing
-#' parameter uncertainty. See Wood, Pya & S{\"a}fken (2016) for more
+#' parameter uncertainty. See Wood, Pya & Säfken (2016) for more
 #' information.
 #'
 #' Models with fixed scale parameters (e.g., negative binomial) do not require
@@ -65,7 +65,7 @@
 #' Methods to Estimate Abundance and Evaluate Conservation Status of Rare
 #' Species. Conservation Biology 25(3), 526-535.
 #'
-#' Wood, S.N., Pya, N. and S{\"a}fken, B. (2016) Smoothing parameter and model
+#' Wood, S.N., Pya, N. and Säfken, B. (2016) Smoothing parameter and model
 #' selection for general smooth models. Journal of the American Statistical
 #' Association, 1-45.
 #'
@@ -75,7 +75,7 @@
 #' @param trace for debugging, see how the scale parameter estimation is going.
 #' @param var.type which variance-covariance matrix should be used (`"Vp"` for
 #' variance-covariance conditional on smoothing parameter(s), `"Vc"` for
-#' unconditional). See [`gamObject`][gamObject] for an details/explanation. If
+#' unconditional). See \code{\link[mgcv]{gamObject}} for an details/explanation. If
 #' in doubt, stick with the default, `"Vp"`.
 #' @param var_type deprecated, use `var.type` instead.
 #' @export
@@ -321,16 +321,28 @@ dsm_varprop <- function(model, newdata=NULL, trace=FALSE, var.type="Vp", var_typ
     class(ret) <- "dsm_varprop"
     return(ret)
   }
-  ## now do some predictions
 
   # make some zeros for the paraPen term so they have no mean effect
   newdata[["XX"]] <- matrix(0, nrow(newdata), ncol(firstD))
 
+  # get the standard errors
+  # if we are using Vc we need to set unconditional=TRUE
+  if(var.type=="Vc"){
+    uncond <- TRUE
+  }else{
+    uncond <- FALSE
+  }
+  # also use this to find the NAs for e.g. soap where we need to remove them
+  preds <- predict(refit, newdata=newdata, type="response", se.fit=TRUE,
+                   unconditional=uncond)
+  ses <- preds$se.fit
+  nas <- is.na(preds$fit)
+
   # get everyone's favourite matrix
-  Lp <- predict(refit, newdata=newdata, type="lpmatrix")
+  Lp <- predict(refit, newdata=newdata, type="lpmatrix")[!nas, ]
   # predictions on the link scale
   pred <- Lp %*% coef(refit)
-  pred <- newdata$off.set * linkinvfn(pred)
+  pred <- newdata$off.set[!nas] * linkinvfn(pred)
 
   # get variance-covariance matrix
   vc <- refit[[var.type]]
@@ -341,15 +353,6 @@ dsm_varprop <- function(model, newdata=NULL, trace=FALSE, var.type="Vp", var_typ
   # make a sandwich
   var_p <- dNdbeta %*% vc %*% t(dNdbeta)
 
-  # if we are using Vc we need to set unconditional=TRUE
-  if(var.type=="Vc"){
-    uncond <- TRUE
-  }else{
-    uncond <- FALSE
-  }
-  # get the standard errors
-  ses <- predict(refit, newdata=newdata, type="response", se.fit=TRUE,
-                 unconditional=uncond)$se.fit
 
   # what should we return?
   ret <- list(old_model = model,
