@@ -1,10 +1,9 @@
-library(dsm)
-library(Distance)
-library(testthat)
-
 par.tol<-1e-5
 
 context("test inputs")
+
+library(Distance)
+
 # load the Gulf of Mexico dolphin data
 data(mexdolphins)
 
